@@ -2,7 +2,7 @@ package fluentd
 
 import (
 	"fmt"
-	"github.com/openshift/cluster-logging-operator/pkg/constants"
+	"github.com/openshift/cluster-logging-operator/internal/constants"
 	"github.com/openshift/cluster-logging-operator/test/framework/e2e"
 	"runtime"
 
@@ -36,7 +36,7 @@ var _ = Describe("[Collection] Provides only a fluentd daemonset", func() {
 
 		AfterEach(func() {
 			framework.Cleanup()
-			framework.WaitForCleanupCompletion(constants.OpenshiftNS, []string{"fluentd"})
+			framework.WaitForCleanupCompletion(constants.OpenshiftNS, []string{constants.CollectorName})
 		}, e2e.DefaultCleanUpTimeout)
 
 		It("should default to a running collector", func() {
